@@ -3,7 +3,6 @@
 """
 #print "module %s" % __name__
 
-
 import exceptions
 import math
 import types
@@ -22,8 +21,6 @@ except ImportError:
     import json
 
 # Import ioflo libs
-
-
 from .globaling import *
 from .odicting import odict
 
@@ -513,7 +510,10 @@ class SocketUdpNb(object):
         # the SO_REUSEADDR flag tells the kernel to reuse a local socket in
         # TIME_WAIT state, without waiting for its natural timeout to expire.
         self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-
+        if self.ss.getsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF) <  self.bs:
+            self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, self.bs)
+        if self.ss.getsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF) < self.bs:
+            self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, self.bs)
         self.ss.setblocking(0) #non blocking socket
 
         #bind to Host Address Port
@@ -666,10 +666,12 @@ class SocketUxdNb(object):
         # the SO_REUSEADDR flag tells the kernel to reuse a local socket in
         # TIME_WAIT state, without waiting for its natural timeout to expire.
         self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-
+        if self.ss.getsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF) <  self.bs:
+            self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, self.bs)
+        if self.ss.getsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF) < self.bs:
+            self.ss.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, self.bs)
         self.ss.setblocking(0) #non blocking socket
 
-
         oldumask = None
         if self.umask is not None: # change umask for the uxd file
             oldumask = os.umask(self.umask) # set new and return old
@@ -772,7 +774,6 @@ class SocketUxdNb(object):
 
         return result
 
-
 #Utility Functions
 
 def TotalSeconds(td):
@@ -897,7 +898,6 @@ def Just(n, seq):
 
 just = Just #alias
 
-
 from abc import ABCMeta,  abstractmethod
 class NonStringIterable:
     """ Check for iterable that is not a string
@@ -1232,7 +1232,6 @@ def CrabSpeed(track = 0.0,  speed = 2.0, north = 0.0, east = 0.0,
 
     return (crab, delta, B + A)
 
-
 def CrossProduct3D(a,b):
     """Forms the 3 dimentional vector cross product of sequences a and b
        a is crossed onto b
@@ -1544,7 +1543,6 @@ def HumanLonToFracDeg(lonDM):
 
     return (lon)
 
-
 def HumanToFracDeg(latDM, lonDM):
     """Converts  pair of coordinates  in human friendly strings of form   DegXMin to
        total fractional degrees where
