@@ -6,6 +6,7 @@
 
 
 from .globaling import *
+from .odicting import odict
 
 from . import registering
 from . import storing 
@@ -46,6 +47,13 @@ class Tasker(registering.StoriedRegistry):
            .schedule = initial scheduling context for this tasker vis a vis skedder
            .runner = generator to run tasker
 
+            The registry class will supply unique name when name is empty by using
+            the .__class__.__name__ as the default preface to the name.
+            To use a different default preface add this to the .__init__ method
+            before the super call
+            
+            if 'preface' not in kw:
+                kw['preface'] = 'MyDefaultPreface'
 
         """
         super(Tasker,self).__init__(**kw)
@@ -88,10 +96,11 @@ class Tasker(registering.StoriedRegistry):
         """
         print "     Task %s status = %s" % (self.name, StatusNames[self.status])
 
-    def resolveLinks(self):
+    def resolve(self, **kwa):
         """Resolves any by name links to other objects   """
-        pass
-
+        parms = odict()
+        return parms
+    
     def start(self):
         """ready runner
 
